@@ -10,13 +10,13 @@ This software is subject to the Apache v2.0 License.
 #include "fwdev.h"
 #include "fwJPEG.h"
 
-OREFR       FwStatus STDCALL PREFIX_OPT(OPT_PREFIX, fwiRGBToY_JPEG_8u_P3C1R)(const Fw8u* const pSrcRGB[3], int srcStep, 
+OREFR OSSE2 FwStatus STDCALL PREFIX_OPT(OPT_PREFIX, fwiRGBToY_JPEG_8u_P3C1R)(const Fw8u* const pSrcRGB[3], int srcStep, 
 							Fw8u* pDstY, int dstStep, FwiSize roiSize);
 OREFR OSSE2 FwStatus STDCALL PREFIX_OPT(OPT_PREFIX, fwiRGBToY_JPEG_8u_C3C1R)(const Fw8u* pSrcRGB, int srcStep,
 							Fw8u* pDstY, int dstStep, FwiSize roiSize);
 
 
-OREFR       FwStatus STDCALL PREFIX_OPT(OPT_PREFIX, fwiBGRToY_JPEG_8u_C3C1R)(const Fw8u* pSrcBGR, int srcStep,
+OREFR OSSE2 FwStatus STDCALL PREFIX_OPT(OPT_PREFIX, fwiBGRToY_JPEG_8u_C3C1R)(const Fw8u* pSrcBGR, int srcStep,
 							Fw8u* pDstY, int dstStep, FwiSize roiSize);
 
 OREFR       FwStatus STDCALL PREFIX_OPT(OPT_PREFIX, fwiRGBToYCbCr_JPEG_8u_P3R)(const Fw8u* const pSrcRGB[3], int srcStep, 
@@ -181,7 +181,7 @@ OREFR       FwStatus STDCALL PREFIX_OPT(OPT_PREFIX, fwiSampleDownH2V2_JPEG_8u_C1
 OREFR OSSE2 FwStatus STDCALL PREFIX_OPT(OPT_PREFIX, fwiSampleDownRowH2V1_Box_JPEG_8u_C1)(const Fw8u* pSrc,int srcWidth, 
 							Fw8u* pDst);
 
-OREFR       FwStatus STDCALL PREFIX_OPT(OPT_PREFIX, fwiSampleDownRowH2V2_Box_JPEG_8u_C1)(const Fw8u* pSrc1, const Fw8u* pSrc2,
+OREFR OSSE2 FwStatus STDCALL PREFIX_OPT(OPT_PREFIX, fwiSampleDownRowH2V2_Box_JPEG_8u_C1)(const Fw8u* pSrc1, const Fw8u* pSrc2,
 							int srcWidth, Fw8u* pDst);
 
 OREFR       FwStatus STDCALL PREFIX_OPT(OPT_PREFIX, fwiSampleUpH2V1_JPEG_8u_C1R)(const Fw8u* pSrc, int srcStep,
