@@ -59,30 +59,35 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiRGBToY_JPEG_8u_P3C1R)(const Fw8u * const pSrc
 	if (pSrcRGB[0] == 0 || pSrcRGB[1] == 0 || pSrcRGB[2] == 0 )
 		return fwStsNullPtrErr;
 
-	STEPCHECK(srcStep, dstStep);
-	ROISIZECHECK(roiSize);
+    RGBToY_JPEG_8u_P3C1R  data;
+    if(roiSize.width>32)
+    {
+        return OPT_LEVEL::fe< RGBToY_JPEG_8u_P3C1R >( data, pSrcRGB[0],srcStep,pSrcRGB[1],srcStep,pSrcRGB[2], srcStep, pDstY, dstStep, roiSize ); 
+    }
+    else
+    {
+		if (pSrcRGB == 0 || pDstY == 0) return fwStsNullPtrErr;
+		STEPCHECK(srcStep, dstStep);
+		ROISIZECHECK(roiSize);
 
-	//DEV code use shift 8 bit data for coeffcients
-	//0.299*256=76.544, 0.587*256=150.272, 0.114*256=29.184
-	//We use 77, 150, 29 as the modified coeff, and then shift the result
-	//The final answer is equal to nearest neighbor rounding
-	//SEE2 should use 16 bit data shift
-	unsigned short result;
-	int x, y;
-	int srcPos, dstPos;
-
-	for (y=0;y<roiSize.height; y++) {
-		srcPos = y*srcStep;
-		dstPos = y*dstStep;
-		for (x=0;x<roiSize.width;x++) {
-			//add 0.5 for nearest neighbor rounding
-			result = 77 * pSrcRGB[0][srcPos] + 150 * pSrcRGB[1][srcPos]
-				+ 29 * pSrcRGB[2][srcPos++] + 128;
-			pDstY [dstPos++] = (Fw8u)(result>>8);
-		}
-	}
-
-	return fwStsNoErr;
+        switch( Dispatch::Type<DT_SSE2>() )
+        {
+        case DT_SSE3:
+        case DT_SSE2:
+                if(roiSize.width ==32 && roiSize.height == 32)
+                {
+                    data.SSE_32(pSrcRGB[0],pSrcRGB[1],pSrcRGB[2],srcStep,pDstY, dstStep);
+                }
+                else
+                    data.REF_CODE(pSrcRGB[0],pSrcRGB[1],pSrcRGB[2],srcStep,pDstY,dstStep,roiSize);
+            break;
+        default:
+            {
+                    data.REF_CODE(pSrcRGB[0],pSrcRGB[1],pSrcRGB[2],srcStep,pDstY,dstStep,roiSize);
+            }
+        }
+	    return fwStsNoErr;
+    }
 }
 
 FwStatus PREFIX_OPT(OPT_PREFIX, fwiRGBToY_JPEG_8u_C3C1R)(const Fw8u *pSrcRGB, int srcStep,
@@ -129,32 +134,35 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiRGBToY_JPEG_8u_C3C1R)(const Fw8u *pSrcRGB, in
 FwStatus PREFIX_OPT(OPT_PREFIX, fwiBGRToY_JPEG_8u_C3C1R)(const Fw8u *pSrcBGR, int srcStep,
 								   Fw8u *pDstY, int dstStep, FwiSize roiSize)
 {
-	if (pSrcBGR == 0 || pDstY == 0) return fwStsNullPtrErr;
-	STEPCHECK(srcStep, dstStep);
-	ROISIZECHECK(roiSize);
+    BGRToY_JPEG_8u_C3C1  data;
+    if(roiSize.width>32)
+    {
+        return OPT_LEVEL::fe< BGRToY_JPEG_8u_C3C1 >( data, pSrcBGR, srcStep, pDstY, dstStep, roiSize ); 
+    }
+    else
+    {
+		if (pSrcBGR == 0 || pDstY == 0) return fwStsNullPtrErr;
+		STEPCHECK(srcStep, dstStep);
+		ROISIZECHECK(roiSize);
 
-	//DEV code use shift 8 bit data for coeffcients
-	//0.299*256=76.544, 0.587*256=150.272, 0.114*256=29.184
-	//We use 77, 150, 29 as the modified coeff, and then shift the result
-	//The final answer is equal to nearest neighbor rounding
-	//SEE2 should use 16 bit data shift
-	unsigned short result;
-	int x, y;
-	int srcPos, dstPos;
-
-	for (y=0;y<roiSize.height; y++) {
-		srcPos = y*srcStep;
-		dstPos = y*dstStep;
-		for (x=0;x<roiSize.width;x++) {
-			//add 0.5 for nearest neighbor rounding
-			result = 29 * pSrcBGR[srcPos] + 150 * pSrcBGR[srcPos+1]
-				+ 77 * pSrcBGR[srcPos+2] + 128;
-			srcPos += 3;
-			pDstY [dstPos++] = (Fw8u)(result>>8);
-		}
-	}
-
-	return fwStsNoErr;
+        switch( Dispatch::Type<DT_SSE2>() )
+        {
+        case DT_SSE3:
+        case DT_SSE2:
+                if(roiSize.width ==32 && roiSize.height == 32)
+                {
+                    data.SSE_32(pSrcBGR,srcStep,pDstY, dstStep);
+                }
+                else
+                    data.REF_CODE(pSrcBGR,srcStep,pDstY,dstStep,roiSize);
+            break;
+        default:
+            {
+                    data.REF_CODE(pSrcBGR,srcStep,pDstY,dstStep,roiSize);
+            }
+        }
+	    return fwStsNoErr;
+    }
 }
 
 //-----------------------------------------------------------------------
@@ -877,12 +885,13 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiCMYKToYCCK_JPEG_8u_C4P4R)(const Fw8u * const
 {
 
     CMYKToYCCK_JPEG_8u_C4P4R  data;
-    if(roiSize.width>32)
-    {
-        return OPT_LEVEL::fec1S4D< CMYKToYCCK_JPEG_8u_C4P4R >( data, pSrcCMYK, srcStep, pDstYCCK[0], dstStep, pDstYCCK[1], dstStep, pDstYCCK[2], dstStep, pDstYCCK[3], dstStep,roiSize ); 
-    }
-    else
-    {
+    //if(roiSize.width>32)
+    //{
+    //    //return OPT_LEVEL::fec1S4D< CMYKToYCCK_JPEG_8u_C4P4R >( data, pSrcCMYK, srcStep, pDstYCCK[0], dstStep, pDstYCCK[1], dstStep, pDstYCCK[2], dstStep, pDstYCCK[3], dstStep,roiSize ); 
+    //    
+    //}
+    //else
+    //{
 	  	if (pSrcCMYK == 0 || pDstYCCK == 0) return fwStsNullPtrErr;
 		if (pDstYCCK[0] == 0 || pDstYCCK[1] == 0 || pDstYCCK[2] == 0 ||
 			pDstYCCK[3] == 0)
@@ -900,6 +909,10 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiCMYKToYCCK_JPEG_8u_C4P4R)(const Fw8u * const
                 {
                     data.SSE_32(pSrcCMYK,srcStep,pDstYCCK[0],pDstYCCK[1],pDstYCCK[2],pDstYCCK[3], dstStep);
                 }
+                else if( roiSize.width > 32)
+                {
+                    data.SSE_CODE(pSrcCMYK,srcStep,pDstYCCK[0],pDstYCCK[1],pDstYCCK[2],pDstYCCK[3], dstStep, roiSize);
+                }
                 else
                     data.REF_CODE(pSrcCMYK,srcStep,pDstYCCK,dstStep,roiSize);
             break;
@@ -909,7 +922,7 @@ FwStatus PREFIX_OPT(OPT_PREFIX, fwiCMYKToYCCK_JPEG_8u_C4P4R)(const Fw8u * const
             }
         }
 	    return fwStsNoErr;
-    }
+    //}
 
 }
 
