@@ -25,6 +25,8 @@ using namespace OPT_LEVEL;
 
 #if BUILD_NUM_AT_LEAST( 102 )
 
+extern SYS_FORCEALIGN_16 Fw16s pedx[64];
+
 //#define USE_C
 
 static int  IdctQuant_SSE2(const Fw16s *pSrc, Fw16s *pDst, const Fw16u *pQuantFwdTable);
@@ -655,7 +657,7 @@ int IdctQuant_LS_SSE2(const Fw16s *pSrc, Fw8u *pDst, int dstStp, const Fw16u *pQ
 	__m128i rxmm0,  rxmm1,  rxmm2,  rxmm3,  rxmm4,  rxmm5,  rxmm6,  rxmm7;
 	__m128i rxmm8,  rxmm9,  rxmm10, rxmm11, rxmm12, rxmm13, rxmm14, rxmm15;
 	__m128i quantCoef;
-    SYS_FORCEALIGN_16 Fw16s pedx[64];
+
 	Fw16s *peax = (Fw16s*)pSrc;
 	Fw16s *pesi, *pecx;
 	Fw8u *pedi  = pDst;
