@@ -1066,7 +1066,7 @@ public:
 
     virtual void RunAll()
     {
-        RunTest( "2.3 4.05 6.786 9.245 1.232 7.89", "2.3 4.05 6.786 0 0 0 ", "1 0" );
+        RunTest( "2.3 4.05 6.786 9.245 1.232 7.89 8.99 9.67 4.56", "2.3 4.05 6.786 0 0 0 0 0 0", "1 0 0" );
         RunTest( "2.3 4.05 6.786 9.245 1.232 7.89 8.99 9.67 4.56", "2.3 4.05 6.786 9.245 1.232 7.89 0 0 0", "1 1 0" );
     }
 };
